Apply a hotfix file and inject the patch definitions

apply_hotfix_file(file, pkg = NULL)

Arguments

file

Path to an R script that defines `patch_list` and optionally `pkg`.

pkg

Optional package name if not provided in the script.

Value

Invisibly TRUE on success.