apply_hotfix_file.Rd
Apply a hotfix file and inject the patch definitions
apply_hotfix_file(file, pkg = NULL)
Path to an R script that defines `patch_list` and optionally `pkg`.
Optional package name if not provided in the script.
Invisibly TRUE on success.