Inject a runtime patch into a locked package namespace
inject_patch(pkg, patch_list, lock = TRUE)
Arguments
- pkg
A package name as a string.
- patch_list
A named list of functions to overwrite in the package namespace.
- lock
Whether to re-lock bindings after patching.
Value
Invisibly TRUE on success.